@@ -4,7 +4,6 @@
 
 import pytest
 
-
 from vulcan_athena import vulcan_athena
 
 
@@ -22,3 +21,7 @@ def test_content(response):
     """Sample pytest test function with the pytest fixture as an argument."""
     # from bs4 import BeautifulSoup
     # assert 'GitHub' in BeautifulSoup(response.content).title.string
+
+
+def test_sqrt_with_param():
+    assert vulcan_athena.sqrt_function(25) == 5
